@@ -34,7 +34,7 @@ import hpccm.templates.tar
 from hpccm.building_blocks.base import bb_base
 from hpccm.building_blocks.intel_psxe_runtime import intel_psxe_runtime
 from hpccm.building_blocks.packages import packages
-from hpccm.common import linux_distro
+from hpccm.common import cpu_arch, linux_distro
 from hpccm.primitives.comment import comment
 from hpccm.primitives.copy import copy
 from hpccm.primitives.environment import environment
@@ -204,6 +204,9 @@ class intel_psxe(bb_base, hpccm.templates.envvars, hpccm.templates.rm,
         self.__bashrc = ''   # Filled in by __distro()
         self.__commands = [] # Filled in by __setup()
 
+        if hpccm.config.g_cpu_arch != cpu_arch.X86_64: # pragma: no cover
+            logging.warning('Using intel_psxe on a non-x86_64 processor')
+
         # Set the Linux distribution specific parameters
         self.__distro()
 
