@@ -22,7 +22,7 @@ from __future__ import print_function
 
 from distutils.version import StrictVersion
 import logging  # pylint: disable=unused-import
-import os
+import posixpath
 
 import hpccm.config
 
@@ -39,6 +39,9 @@ class copy(object):
     identifier.  This also causes the Singularity block to named
     `%appfiles` rather than `%files` (Singularity specific).
 
+    _chown: Set the ownership of the file(s) in the container image
+    (Docker specific).
+
     dest: Path in the container image to copy the file(s)
 
     files: A dictionary of file pairs, source and destination, to copy
@@ -85,6 +88,7 @@ class copy(object):
         #super(copy, self).__init__()
 
         self._app = kwargs.get('_app', '')  # Singularity specific
+        self.__chown = kwargs.get('_chown', '')  # Docker specific
         self.__dest = kwargs.get('dest', '')
         self.__files = kwargs.get('files', {})
         self.__from = kwargs.get('_from', '')  # Docker specific
@@ -133,6 +137,10 @@ class copy(object):
             # COPY src2 dest2
             # COPY src3 dest3
             base_inst = 'COPY '
+
+            if self.__chown:
+                base_inst = base_inst + '--chown={} '.format(self.__chown)
+
             if self.__from:
                 base_inst = base_inst + '--from={} '.format(self.__from)
 
@@ -150,7 +158,7 @@ class copy(object):
                     c[0] = c[0] + src[0]
                     c.extend(['    {}'.format(x) for x in src[1:]])
                     # Docker requires a trailing slash.  Add one if missing.
-                    c.append('    {}'.format(os.path.join(dest, '')))
+                    c.append('    {}'.format(posixpath.join(dest, '')))
                 else:
                     c[0] = c[0] + '{0} {1}'.format(src, dest)
 
@@ -199,10 +207,10 @@ class copy(object):
                         flat_files.append('    {0} {1}'.format(s, dest))
 
                         if self._post:
-                            post.append('    mv /{0} {1}'.format(os.path.basename(s), os.path.join(pair['dest'], s)))
+                            post.append('    mv /{0} {1}'.format(posixpath.basename(s), posixpath.join(pair['dest'], s)))
                     if (self._mkdir and
-                        os.path.dirname(dest) != '/' and
-                        os.path.basename(dest) != dest):
+                        posixpath.dirname(dest) != '/' and
+                        posixpath.basename(dest) != dest):
                         # When multiple files are to be copied to the
                         # same destination, assume the destination is
                         # a directory
@@ -210,14 +218,14 @@ class copy(object):
                 else:
                     flat_files.append('    {0} {1}'.format(src, dest))
                     if (self._mkdir and
-                        os.path.dirname(dest) != '/' and
-                        os.path.basename(dest) != dest):
+                        posixpath.dirname(dest) != '/' and
+                        posixpath.basename(dest) != dest):
                         # When a single file is to be copied to a
                         # destination, assume the destination is a
                         # file.
-                        pre.append('    mkdir -p ${{SINGULARITY_ROOTFS}}{0}'.format(os.path.dirname(dest)))
+                        pre.append('    mkdir -p ${{SINGULARITY_ROOTFS}}{0}'.format(posixpath.dirname(dest)))
                     elif self._post:
-                        post.append('    mv /{0} {1}'.format(os.path.basename(src), pair['dest']))
+                        post.append('    mv /{0} {1}'.format(posixpath.basename(src), pair['dest']))
 
             s = ''
             if pre:
